Crate pool_sync_mantle

Crate pool_sync_mantle 

PoolSync: A library for synchronizing and managing liquidity pools on Mantle network

This library provides functionality to interact with and synchronize data from multiple DeFi protocols (UniswapV3, Agni, MerchantMoe) on the Mantle blockchain network.

Macros

impl_pool_info
Macro for generating getter methods for all of the suppored pools

Structs

PoolSync
The main struct for pool synchronization
Rpc
UniswapV3Pool

Enums

Chain
Enum representing supported blockchain networks
Pool
Represents a populated pool from any of the supported protocols
PoolType
Enumerates the supported pool types

Traits

PoolInfo
Defines common methods that are used to access information about the pools